consolelog

package
v0.6.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 12, 2026 License: AGPL-3.0, AGPL-3.0-or-later Imports: 12 Imported by: 0

Documentation

Overview

Package consolelog streams console logs from Steam's CEF debugger via CDP.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Collector

type Collector struct {
	// contains filtered or unexported fields
}

Collector streams console logs from Steam's CEF debugger to the Hub.

func NewCollector

func NewCollector(sendFn func(protocol.ConsoleLogBatch)) *Collector

NewCollector creates a new console log collector. sendFn is called each flush with a batch of entries.

func (*Collector) GetLevelMask

func (c *Collector) GetLevelMask() uint32

GetLevelMask returns the current log level bitmask filter.

func (*Collector) IsRunning

func (c *Collector) IsRunning() bool

IsRunning returns true if the collector is currently active.

func (*Collector) SetLevelMask

func (c *Collector) SetLevelMask(mask uint32)

SetLevelMask sets the log level bitmask filter.

func (*Collector) Start

func (c *Collector) Start()

Start begins streaming console logs from CDP. If already running, this is a no-op.

func (*Collector) Stop

func (c *Collector) Stop()

Stop halts the console log streaming.

Jump to